Repeater

Struct Repeater 

pub struct Repeater<E>
where E: RepeaterEntry + Clone + Unpin + Send,
{ /* private fields */ }
Repeats structs after user defined Duration.

Implementations

Source

impl<E> Repeater<E>
where E: RepeaterEntry + Clone + Unpin + Send + Sync,

pub fn with_capacity(capacity: usize) -> Self

Create a new repeater with given capacity

Examples found in repository?
examples/simple.rs (line 36)
32async fn main() {
33    let callback = |entry, _| async move { println!("Popped {entry:?}") };
34
35    // create and start the repeater
36    let handle = async_repeater::Repeater::with_capacity(25).run_with_async_callback(callback);
37
38    // create entries with the same interval
39    let dur = Duration::from_secs(5);
40    let repetition = vec![Entry::new(0, dur), Entry::new(1, dur), Entry::new(2, dur)];
41
42    // insert the entries into the repeater with 1 second delay in between
43    for repetition in repetition {
44        handle.insert(repetition).await.unwrap();
45        tokio::time::sleep(Duration::from_secs(1)).await;
46    }
47
48    // wait for a ctrl-c.
49    // If this wasn't there, the program would exit immidiatly without running
50    // a single repetition
51    tokio::signal::ctrl_c().await.unwrap();
52    handle.stop().await.unwrap();
53    println!("Stopping cycler");
54}
More examples
Hide additional examples
examples/stream_impl.rs (line 37)
35async fn main() {
36    // create but not start the repeater
37    let mut repeater = Repeater::<Entry>::with_capacity(7);
38
39    // create entries as a stream
40    let repetitions = tokio_stream::iter(vec![
41        Entry::new(0, Duration::from_millis(3000)),
42        Entry::new(1, Duration::from_millis(1000)),
43        Entry::new(2, Duration::from_millis(2000)),
44    ]);
45    tokio::pin!(repetitions);
46
47    // select either an element from the stream or
48    // an element from the repeater or
49    // from the ctrl-c signal
50    loop {
51        tokio::select! {
52            Some(item) = repeater.next() => {
53                println!("Popped: {item:?}");
54                repeater.insert(item);
55            }
56            Some(item) = repetitions.next() => {
57                repeater.insert(item);
58            }
59            _ = tokio::signal::ctrl_c() => {
60                break
61            }
62        }
63    }
64}
pub fn insert(&mut self, e: E)

Insert entry into repeater

If entry with same key already exists, it will be replaced. Replacement will also reset the repetition.

Insertion respects the delay() call

Examples found in repository?
examples/stream_impl.rs (line 54)
35async fn main() {
36    // create but not start the repeater
37    let mut repeater = Repeater::<Entry>::with_capacity(7);
38
39    // create entries as a stream
40    let repetitions = tokio_stream::iter(vec![
41        Entry::new(0, Duration::from_millis(3000)),
42        Entry::new(1, Duration::from_millis(1000)),
43        Entry::new(2, Duration::from_millis(2000)),
44    ]);
45    tokio::pin!(repetitions);
46
47    // select either an element from the stream or
48    // an element from the repeater or
49    // from the ctrl-c signal
50    loop {
51        tokio::select! {
52            Some(item) = repeater.next() => {
53                println!("Popped: {item:?}");
54                repeater.insert(item);
55            }
56            Some(item) = repetitions.next() => {
57                repeater.insert(item);
58            }
59            _ = tokio::signal::ctrl_c() => {
60                break
61            }
62        }
63    }
64}
pub fn remove(&mut self, key: &E::Key)

Remove entry with key from repeater

pub fn clear(&mut self)

Clear the repeater. This removes all entries.

pub fn len(&self) -> usize

Number of entries in the repeater

pub fn is_empty(&self) -> bool

Return true if repeater is empty

pub fn run_with_async_callback<F, Fut>(self, callback: F) -> RepeaterHandle<E>
where F: FnOnce(E, RepeaterHandle<E>) -> Fut + Send + 'static + Clone, Fut: Future<Output = ()> + Send + 'static,

Starts the repeater in a background task

This consumes the repeater and returns a RepeaterHandle which allows communication with the background task.

Examples found in repository?
examples/simple.rs (line 36)
32async fn main() {
33    let callback = |entry, _| async move { println!("Popped {entry:?}") };
34
35    // create and start the repeater
36    let handle = async_repeater::Repeater::with_capacity(25).run_with_async_callback(callback);
37
38    // create entries with the same interval
39    let dur = Duration::from_secs(5);
40    let repetition = vec![Entry::new(0, dur), Entry::new(1, dur), Entry::new(2, dur)];
41
42    // insert the entries into the repeater with 1 second delay in between
43    for repetition in repetition {
44        handle.insert(repetition).await.unwrap();
45        tokio::time::sleep(Duration::from_secs(1)).await;
46    }
47
48    // wait for a ctrl-c.
49    // If this wasn't there, the program would exit immidiatly without running
50    // a single repetition
51    tokio::signal::ctrl_c().await.unwrap();
52    handle.stop().await.unwrap();
53    println!("Stopping cycler");
54}