RepeaterHandle

Struct RepeaterHandle 

pub struct RepeaterHandle<E>
where E: RepeaterEntry + Clone + Unpin + 'static,
{ /* private fields */ }
Used to communicate with the repeater task

Returned after the call to Repeater::run_with_async_callback

Implementations

Source

impl<E> RepeaterHandle<E>
where E: RepeaterEntry + Clone + Unpin + 'static,

pub async fn insert(&self, e: E) -> Result<(), ConnectionLost>

Insert entry into Repeater

Examples found in repository?
examples/simple.rs (line 44)
32async fn main() {
33    let callback = |entry, _| async move { println!("Popped {entry:?}") };
34
35    // create and start the repeater
36    let handle = async_repeater::Repeater::with_capacity(25).run_with_async_callback(callback);
37
38    // create entries with the same interval
39    let dur = Duration::from_secs(5);
40    let repetition = vec![Entry::new(0, dur), Entry::new(1, dur), Entry::new(2, dur)];
41
42    // insert the entries into the repeater with 1 second delay in between
43    for repetition in repetition {
44        handle.insert(repetition).await.unwrap();
45        tokio::time::sleep(Duration::from_secs(1)).await;
46    }
47
48    // wait for a ctrl-c.
49    // If this wasn't there, the program would exit immidiatly without running
50    // a single repetition
51    tokio::signal::ctrl_c().await.unwrap();
52    handle.stop().await.unwrap();
53    println!("Stopping cycler");
54}
pub async fn remove(&self, key: E::Key) -> Result<(), ConnectionLost>

Remove entry from Repeater

pub async fn clear(&self) -> Result<(), ConnectionLost>

Remove all entries from Repeater

pub async fn stop(self) -> Result<(), ConnectionLost>

Stop a Repeater

Examples found in repository?
examples/simple.rs (line 52)
32async fn main() {
33    let callback = |entry, _| async move { println!("Popped {entry:?}") };
34
35    // create and start the repeater
36    let handle = async_repeater::Repeater::with_capacity(25).run_with_async_callback(callback);
37
38    // create entries with the same interval
39    let dur = Duration::from_secs(5);
40    let repetition = vec![Entry::new(0, dur), Entry::new(1, dur), Entry::new(2, dur)];
41
42    // insert the entries into the repeater with 1 second delay in between
43    for repetition in repetition {
44        handle.insert(repetition).await.unwrap();
45        tokio::time::sleep(Duration::from_secs(1)).await;
46    }
47
48    // wait for a ctrl-c.
49    // If this wasn't there, the program would exit immidiatly without running
50    // a single repetition
51    tokio::signal::ctrl_c().await.unwrap();
52    handle.stop().await.unwrap();
53    println!("Stopping cycler");
54}
pub async fn len(self) -> Result<usize, ConnectionLost>

Return the number of entries in Repeater

pub async fn is_empty(self) -> Result<bool, ConnectionLost>

Return true if no entries are inside of Repeater